-----------------------------------
-----------------------------------
-- Whisp by Anea
-----------------------------------
-- options.lua
-- Commandline and FuBar options
-----------------------------------

local L = AceLibrary("AceLocale-2.2"):new("Whisp")

-- generic options
local options = {
  type = "group",
  name = L["options"],
  desc = L["setup this mod to your needs"],
  order = 4,
  args = {
    lock = {
      type = "toggle",
      name = L["lock"],
      desc = L["locks the chatbox tooltip"],
      order = 1,
      set = function(v) Whisp.db.char.locked = v  end,
      get = function() return Whisp.db.char.locked end,
    },
    growth = {
      type = "toggle",
      name = L["grow up"],
      desc = L["toggle wether the chatbox tooltip should grow up or down"],
      order = 4,
      set = function(v) Whisp.db.char.growUp = v end,
      get = function() return Whisp.db.char.growUp end,
    },  
    reset = {
      type = "execute",
      name = L["reset"],
      desc = L["reset the position of the chatbox tooltip"],
      order = 4,
      func = function(v) Whisp:ResetEditBoxFrame() end,
    },  

    linesShown = {
      type = "range",
      order = 6,
      name = L["lines shown"],
      desc = L["the number of lines to show in the tooltips"],
      min = 1,
      max = 30,
      step = 1,
      set = function(v) Whisp.db.char.linesShown=v end,
      get = function() return Whisp.db.char.linesShown end,
    },

    timeout = {
      type = "range",
      order = 7,
      name = L["cache"],
      desc = L["how long should messages be cached (in minutes)"],
      min = 1,
      max = 600,
      step = 1,
      set = function(v) Whisp.db.profile.timeout=v end,
      get = function() return Whisp.db.profile.timeout end,
    },
    
    background = {
     type = "color",
     order = 8,
     name = L["background color"],
     desc = L["set the background color of the tooltips"],
     hasAlpha = true,
     get = function()
      local c = Whisp.db.char.colorBackground
      return c[1], c[2], c[3], c[4]
     end,
     set = function(r, g, b, a)
       Whisp.db.char.colorBackground = {r, g, b, a}
       Whisp:UpdateBackgroundColor(Whisp.tooltipFrame)
       Whisp:UpdateBackgroundColor(Whisp.editBoxFrame)
     end,
    },
  },
}

Whisp.slashcommands = {
  type = "group",
  args = {}
}
  
-- fubar commands
Whisp.fucommands = {
}

  
-- Setup fubar
Whisp.title = "Whisp"
Whisp.hasIcon = true
Whisp.hideWithoutStandby = true
Whisp.independentProfile = false

-- fubar selected listitems
Whisp.reportIndex = {}

function Whisp:SetupOptions()
  -- Setup menu entries
  self.slashcommands.args.options =  options
  self:RegisterChatCommand({"/whisp"}, self.slashcommands)
  
  self.fucommands =  options
  self.fucommands.args.fuoptions = {
      type = "group",
      name = L["FuBar options"],
      desc = L["set the FuBar options"],
      order = 1000,
      args = {}
    }
  self.overrideMenu = true
end

-- Create menu dynamically to avoid default fubar-options
local dewdrop = AceLibrary("Dewdrop-2.0")
function Whisp:OnMenuRequest(level, value, inTooltip, v1, v2, v3)
  dewdrop:FeedAceOptionsTable(Whisp.fucommands)
  
  if value=="fuoptions" or v1=="fuoptions" or v2=="fuoptions" or v3=="fuoptions" then
    self:AddImpliedMenuOptions(2)
  end
end
